/* Backtracing
   Copyright (c) 2010 Networked Systems Group, University of Kaiserslautern

This file is part of the Imote2 Image Loader.

The Imote2 Image Loader is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

The Imote2 Image Loader is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the Imote2 Image Loader. If not, see <http://www.gnu.org/licenses/>.
*/
#include <inttypes.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "exception.h"

/* C++ Name Demangling: defined by libstdc++ */
char * __cxa_demangle(const char * mangled_name,
	char * Output_buffer, size_t * length, int * status);

/* C++ Name Demangling: defined by libstdc++ of gcc */
int __gcclibcxx_demangle_callback(const char * mangled_name,
	void (*callback)(const char*, size_t, void*), void * opaque);

inline static bool isACPS(const uint32_t * fp) {
	return (fp[-2] == (uint32_t)(fp + 1));
}

inline static const uint32_t getLR(const uint32_t * fp, bool acps) {
	return fp[acps ? -1 : 0];
}

inline static const uint32_t * popFrame(const uint32_t * fp, bool acps) {
	return (const uint32_t*)(fp[acps ? -3 : -1]);
}

static void _excBacktraceRewind();

static bool _excBacktraceInDemangling = FALSE;
static bool _excBacktraceDemangleNames = TRUE;

extern void * __text_start;
extern void * __text_end;

#ifdef USE_GXX_DEMANGLE
static void cbDemangle(const char * txt, size_t len, void * arg) {
	char buf[len + 1];
	strncpy(buf, txt, len);
	buf[len] = '\0';
	_excUartOut(buf);
}
#endif

static inline void printFunctionName(const uint32_t * fp, bool acps) {
	/* try to get the functions name */
	if (acps) {
		/* when using -fpoke-function-name the GCC will use APCS conventions
		 * by default. Thus if we do not have an APCS frame, we won't have
		 * a name for that function */
		
		/* When an APCS conforming function is entered, it stores the current
		 * PC value into its frame. From that we can determine the location
		 * of the function start. If the name of the function is stored in
		 * the code (-fpoke-function-name), it is stored right BEFORE the
		 * functions start address.
		 * The function name itself consists of a length field, which is
		 * stored as a 3-byte value and prefixed by 0xff and before that
		 * length value the name itself is stored as a NUL-terminated
		 * string. Thus we have (from lower to higher address):
		 *  - the name as NUL-terminated string , aligned on 4-byte
		 *  - the length of that string ORed with 0xff000000 as a word
		 *  - the function start
		 */
		
		const uint32_t * pc = (const uint32_t*)(fp[0]);
		/* sanity check wether pc inside text segment */
		if ((uint32_t)pc < (uint32_t)&__text_start ||
			(uint32_t)pc > (uint32_t)&__text_end) {
			_excUartOut("<PC is not inside .text segment>\n");
		}
		
		const char * name;
		
		/* since the PC is already advanced by the time it is stored and
		 * the string length is stored before the function, we have to
		 * go backward from that pc value to read the length */
		int32_t lenOff = -4;
		uint32_t len = pc[lenOff];
		if (len >> 24 != 0xff) {
			/* the length must begin with 0xff, which is some kind of
			 * magic. If it does not, we try to get the length one word
			 * before the address we just tried. This is because the
			 * exception handlers (for example) have one more instruction
			 * before saving the pc, the adding an offset of one word */
			lenOff--;
			len = pc[lenOff];
		}
		if (len >> 24 == 0xff) {
			/* if the magic matches (maybe after re-adjusting), we can
			 * read the actual length and get a pointer to the name */
			len &= 0x00ffffff;
			name = ((const char*)(pc + lenOff)) - len;
		} else name = NULL;
		
		if (name && _excBacktraceDemangleNames &&
			len > 2 && name[0] == '_' && name[1] == 'Z') {
#ifdef USE_GXX_DEMANGLE
			_excBacktraceInDemangling = TRUE;
			int stat = __gcclibcxx_demangle_callback(name, &cbDemangle, NULL);
			_excBacktraceInDemangling = FALSE;
			if (stat) {
				char buf[600];
				snprintf(buf, sizeof(buf), "  <error when demangling name>\n"
					"    unmangled name is %s\n", name);
				_excUartOut(buf);
				return;
			} else {
				_excUartOut("\n");
			}
#else
			/* use stdc++ abi */
			int stat;
			char nameBuf[400];
			size_t blen = sizeof(nameBuf);
			/* demangle the function name */
			_excBacktraceInDemangling = TRUE;
			char * lname = __cxa_demangle(name, nameBuf, &blen, &stat);
			_excBacktraceInDemangling = FALSE;
			if (lname && !stat) {
				size_t i;
				bool printable = TRUE;
				for(i = 0; i < blen && lname[i] != '\0'; ++i) {
					if (lname[i] < ' ' || lname[i] > '~') {
						printable = FALSE;
						break;
					}
				}
				if (printable) name = lname;
			}
			_excUartOut(name);
			_excUartOut("\n");
#endif
			
			return;
		} else if (name && name[0] != '\0') {
			_excUartOut(name);
			_excUartOut("\n");
			return;
		} /* else fall through */
	}
	
	/* if no name could be found, insert '??' for that */
	_excUartOut("<??" ">\n");
}

/** \brief reduced processor state (r0-r14 without r12) */
__attribute__((used))
static uint32_t _excProcessorState[14];

void _excBacktraceDoubleFault() {
	if (_excBacktraceInDemangling) {
		_excUartOut("Backtrace: Fault occured while demangling names, "
			"switching off demangling and retracing\n");
		_excBacktraceDemangleNames = FALSE;
		_excBacktraceRewind();
	}
}

/** \brief save processor state in global variable and act as trampoline
 *  to real backtrace function.
 * If the real backtrace function should fail (and raise a double-fault
 *  therefore), the double-fault handler will recognize this and restore the
 *  this processor state and the previous state (see _excBacktraceRewind())
 *  but that time name demangling will be disabled
 * \param lr contents of LR register
 * \param fp contents of FP register
 * \note naked function such that no frame is created (i.e. no registers are
 *  altered by the compiled code of that function) */
__attribute__((naked))
void _excBacktrace(uint32_t lr, register const uint32_t * fp) {
	asm volatile(
		/* get global variable into ip register */
		"ldr ip, =_excProcessorState\n\t"
		/* store all caller-saved registers */
		"stmia ip, {r0-r11,r13-r14}\n\t"
		/* jump into real backtrace function */
		"b _excBacktraceReal\n\t"
	);
}

/** \brief restore processor state from global variable (which was recorded
 * before the backtrace algorithm did its work (and failed thereby)) and
 * restore the processor mode before the double-fault was raised */
__attribute__((naked,noreturn))
static void _excBacktraceRewind() {
	asm volatile(
		/* restore all caller-saved registers: switch to old mode
		 *  to restore shadowed registers as well */
		"mrs ip, spsr\n\t"
		"orr ip, #0xc0\n\t"
		"msr cpsr_c, ip\n\t"
		/* get global variable (old processor state) into ip register */
		"ldr ip, =_excProcessorState\n\t"
		/* now restore registers */
		"ldmia ip, {r0-r11,r13-r14}\n\t"
		/* switch back to previous mode and jump into backtrace again */
		"ldr ip, =_excBacktraceReal\n\t"
		"movs pc, ip"
	);
	/* keep gcc from warning...*/
	while(TRUE);
}

/** \brief print a backtrace
 * \param lr contents of LR register
 * \param fp contents of FP register */
__attribute__((used))
static void _excBacktraceReal(uint32_t lr, register const uint32_t * fp) {
	char buf[100];
	int frame = 0;
	
	/* to understand the following operations, you first have to understand
	 * what happens if a function is called. The important two things are
	 * 1) When a function is called, the lr register contains the address
	 *    to jump back when the function returns. The register is saved into
	 *    the called functions frame
	 * 2) The fp register of the caller is saved into the called functions
	 *    frame
	 * now let for example hplarmv_dabort call this backtrace function here:
	 *  in that case the lr argument (not our lr REGISTER here but the
	 *  argument!) is set the to lr value of hplarmv_dabort which points into
	 *  the function which caused (called) hplarmv_dabort. The fp argument
	 *  is set to the fp value of hplarmv_dabort, denoting that functions frame.
	 *  That in turn means that the frame (fp) must be popped one time to
	 *  correspond to the same function which lr points to.
	 */
	
	fp = popFrame(fp, isACPS(fp));
	
	/* fp is initialized with NULL by the loader. Thus, if fp is NULL we have
	 *  reached the loader and thus the previously printed frame was the first
	 *  one (which is the last one in the orderer of printing...since this is a
	 *  BACKtrace) */
	while (fp != NULL) {
		++frame;
		
		/* determine calling convention (acps / non acps) which in turn
		 * determines the frame layout */
		bool acps = isACPS(fp);
		
		/* now print all information */
		snprintf(buf, sizeof(buf), " #%02d at 0x%08x in ", frame, lr - 4);
		_excUartOut(buf);
		printFunctionName(fp, acps);
		
		/* advance to previous frame: lr is read from the current frame and
		 * then the corresponding fp is calculated by going back one frame */
		lr = getLR(fp, acps);
		fp = popFrame(fp, acps);
	}
}

