/* MMU Table
   Copyright (c) 2010 Networked Systems Group, University of Kaiserslautern

This file is part of the Imote2 Image Loader.

The Imote2 Image Loader is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

The Imote2 Image Loader is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the Imote2 Image Loader. If not, see <http://www.gnu.org/licenses/>.
*/

#include <inttypes.h>
#include <core/mmu.h>
#include <core/core.h>

/** \file mmu_table.c
 * \brief holds the mmu table and activates the MMU */

/** \brief an 1 MiB Descriptor in the mmu table
 * \note look at the XScale Core Manual on Page 2.3.2-30 */
struct SectionDescriptor {
	/** \brief Type of the Descriptor: always 2 for 1 MiB Descriptors */
	uint32_t type : 2;
	/** \brief buffering (aka. WRITE BACK) */
	uint32_t buffer : 1;
	/** \brief instruction and data caching */
	uint32_t cache : 1;
	/** \brief always zero */
	uint32_t _zero0 : 1;
	/** \brief descriptor domain */
	uint32_t domain : 4;
	uint32_t p : 1;
	uint32_t ap : 2;
	/** \brief type extension, not further used */
	uint32_t tex : 4;
	/** \brief always zero */
	uint32_t _zero1 : 4;
	/** \brief descriptor base address */
	uint32_t base : 12;
} __attribute__((packed));

/** Instruction and Data Caching for the different Memory Regions */
enum {
	/** \brief sram caching */
	CACHE_SRAM = 1,
	/** \brief flash memory caching */
	CACHE_FLASH = 1,
	/** \brief flash memory, partition zero caching
	 not recommended when reading flash status information */
	CACHE_FLASH_ZERO = 1,
	/** \brief sdram caching */
	CACHE_SDRAM = 1,
	/** \brief compact flash caching */
	CACHE_CF = 1,

	/** \brief constant value for NOT caching specific regions
	 * DO NOT CHANGE THIS! */
	CACHE_NEVER = 0,
	/** \brief constant value for caching specific regions
	 * DO NOT CHANGE THIS! */
	CACHE_ALWAYS = 1,
};

/** Buffering (aka. WRITE BACK) */
enum {
	/** \brief sram and sdram buffering */
	BUFFER_RAM = 0,

	/** \brief compact flash buffering */
	BUFFER_CF = 0,

	/** \brief constant value for NOT buffering specific regions
	 * DO NOT CHANGE THIS! */
	BUFFER_NEVER = 0,
};

/** \brief Descriptor Types */
enum {
	TYPE_NOACCESS = 0,
	/* 1 MiB Descriptor */
	TYPE_1MIB = 2,
};

/** \brief the mmu table for the Imote 2
 * \note look at the Intel PXA27x Developers Manual on Chapter 28.1 */
__attribute__((aligned(0x4000)))
const struct SectionDescriptor _mmuTable[4 * 1024] =
{
	/* Covering 0 - 31 MiB: Flash Memory */
	[0] =
#ifndef REMAP_EXCEPTION_VECTORS
	{ .base =    0, .cache = CACHE_FLASH_ZERO, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    1, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    2, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    3, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
#else
	{ .base =    4, .cache = CACHE_FLASH_ZERO, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    5, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    6, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    7, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
#endif
	{ .base =    4, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    5, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    6, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    7, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    8, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    9, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   10, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   11, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   12, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   13, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   14, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   15, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   16, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   17, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   18, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   19, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   20, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   21, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   22, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   23, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   24, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   25, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   26, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   27, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   28, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   29, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   30, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   31, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },

	/* Covering 32 - 63 MiB: remapped to 0 - 31 MiB */
	[32] =
	{ .base =    0, .cache = CACHE_FLASH_ZERO, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    1, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    2, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    3, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    4, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    5, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    6, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    7, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    8, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =    9, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   10, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   11, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   12, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   13, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   14, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   15, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   16, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   17, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   18, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   19, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   20, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   21, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   22, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   23, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   24, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   25, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   26, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   27, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   28, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   29, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   30, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base =   31, .cache = CACHE_FLASH, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },

	/* Covering 64 - 64 MiB: unconnected, but cacheable for
		dCacheCleanAndInvalidateLine to clean the data cache */
	[64] =
	{ .base =   64, .cache = CACHE_ALWAYS, .cache = CACHE_NEVER, .type = TYPE_1MIB },

	/* Covering 65 - 511 MiB: unconnected */
	[65] = {},

	/* Covering 512 - 1023 MiB: PC Card / CF */
	[512] =
	{ .base =  512, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  513, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  514, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  515, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  516, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  517, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  518, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  519, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  520, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  521, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  522, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  523, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  524, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  525, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  526, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  527, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  528, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  529, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  530, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  531, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  532, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  533, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  534, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  535, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  536, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  537, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  538, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  539, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  540, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  541, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  542, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  543, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  544, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  545, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  546, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  547, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  548, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  549, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  550, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  551, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  552, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  553, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  554, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  555, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  556, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  557, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  558, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  559, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  560, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  561, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  562, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  563, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  564, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  565, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  566, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  567, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  568, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  569, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  570, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  571, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  572, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  573, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  574, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  575, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  576, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  577, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  578, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  579, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  580, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  581, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  582, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  583, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  584, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  585, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  586, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  587, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  588, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  589, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  590, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  591, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  592, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  593, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  594, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  595, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  596, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  597, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  598, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  599, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  600, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  601, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  602, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  603, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  604, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  605, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  606, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  607, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  608, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  609, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  610, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  611, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  612, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  613, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  614, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  615, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  616, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  617, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  618, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  619, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  620, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  621, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  622, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  623, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  624, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  625, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  626, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  627, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  628, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  629, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  630, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  631, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  632, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  633, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  634, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  635, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  636, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  637, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  638, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  639, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  640, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  641, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  642, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  643, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  644, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  645, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  646, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  647, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  648, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  649, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  650, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  651, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  652, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  653, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  654, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  655, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  656, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  657, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  658, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  659, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  660, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  661, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  662, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  663, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  664, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  665, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  666, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  667, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  668, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  669, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  670, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  671, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  672, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  673, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  674, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  675, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  676, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  677, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  678, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  679, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  680, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  681, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  682, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  683, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  684, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  685, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  686, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  687, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  688, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  689, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  690, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  691, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  692, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  693, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  694, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  695, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  696, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  697, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  698, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  699, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  700, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  701, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  702, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  703, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  704, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  705, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  706, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  707, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  708, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  709, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  710, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  711, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  712, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  713, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  714, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  715, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  716, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  717, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  718, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  719, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  720, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  721, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  722, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  723, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  724, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  725, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  726, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  727, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  728, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  729, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  730, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  731, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  732, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  733, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  734, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  735, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  736, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  737, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  738, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  739, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  740, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  741, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  742, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  743, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  744, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  745, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  746, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  747, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  748, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  749, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  750, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  751, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  752, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  753, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  754, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  755, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  756, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  757, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  758, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  759, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  760, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  761, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  762, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  763, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  764, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  765, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  766, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  767, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  768, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  769, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  770, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  771, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  772, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  773, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  774, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  775, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  776, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  777, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  778, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  779, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  780, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  781, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  782, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  783, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  784, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  785, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  786, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  787, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  788, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  789, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  790, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  791, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  792, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  793, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  794, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  795, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  796, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  797, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  798, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  799, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  800, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  801, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  802, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  803, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  804, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  805, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  806, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  807, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  808, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  809, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  810, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  811, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  812, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  813, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  814, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  815, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  816, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  817, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  818, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  819, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  820, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  821, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  822, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  823, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  824, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  825, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  826, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  827, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  828, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  829, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  830, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  831, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  832, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  833, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  834, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  835, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  836, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  837, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  838, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  839, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  840, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  841, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  842, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  843, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  844, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  845, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  846, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  847, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  848, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  849, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  850, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  851, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  852, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  853, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  854, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  855, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  856, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  857, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  858, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  859, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  860, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  861, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  862, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  863, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  864, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  865, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  866, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  867, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  868, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  869, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  870, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  871, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  872, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  873, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  874, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  875, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  876, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  877, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  878, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  879, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  880, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  881, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  882, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  883, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  884, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  885, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  886, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  887, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  888, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  889, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  890, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  891, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  892, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  893, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  894, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  895, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  896, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  897, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  898, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  899, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  900, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  901, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  902, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  903, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  904, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  905, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  906, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  907, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  908, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  909, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  910, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  911, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  912, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  913, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  914, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  915, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  916, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  917, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  918, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  919, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  920, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  921, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  922, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  923, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  924, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  925, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  926, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  927, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  928, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  929, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  930, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  931, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  932, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  933, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  934, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  935, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  936, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  937, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  938, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  939, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  940, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  941, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  942, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  943, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  944, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  945, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  946, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  947, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  948, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  949, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  950, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  951, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  952, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  953, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  954, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  955, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  956, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  957, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  958, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  959, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  960, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  961, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  962, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  963, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  964, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  965, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  966, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  967, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  968, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  969, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  970, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  971, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  972, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  973, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  974, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  975, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  976, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  977, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  978, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  979, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  980, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  981, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  982, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  983, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  984, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  985, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  986, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  987, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  988, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  989, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  990, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  991, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  992, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  993, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  994, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  995, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  996, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  997, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  998, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base =  999, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1000, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1001, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1002, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1003, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1004, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1005, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1006, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1007, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1008, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1009, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1010, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1011, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1012, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1013, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1014, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1015, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1016, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1017, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1018, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1019, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1020, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1021, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1022, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },
	{ .base = 1023, .cache = CACHE_CF, .buffer = BUFFER_CF, .type = TYPE_1MIB },

	/* Covering 1024 - 1471 MiB: Internal Registers (Peripherals) */
	[1024] =
	{ .base = 1024, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1025, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1026, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1027, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1028, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1029, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1030, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1031, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1032, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1033, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1034, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1035, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1036, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1037, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1038, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1039, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1040, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1041, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1042, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1043, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1044, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1045, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1046, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1047, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1048, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1049, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1050, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1051, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1052, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1053, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1054, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1055, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1056, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1057, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1058, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1059, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1060, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1061, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1062, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1063, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1064, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1065, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1066, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1067, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1068, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1069, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1070, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1071, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1072, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1073, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1074, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1075, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1076, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1077, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1078, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1079, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1080, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1081, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1082, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1083, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1084, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1085, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1086, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1087, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1088, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1089, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1090, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1091, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1092, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1093, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1094, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1095, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1096, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1097, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1098, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1099, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1100, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1101, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1102, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1103, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1104, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1105, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1106, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1107, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1108, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1109, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1110, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1111, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1112, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1113, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1114, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1115, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1116, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1117, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1118, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1119, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1120, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1121, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1122, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1123, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1124, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1125, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1126, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1127, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1128, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1129, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1130, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1131, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1132, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1133, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1134, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1135, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1136, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1137, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1138, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1139, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1140, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1141, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1142, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1143, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1144, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1145, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1146, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1147, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1148, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1149, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1150, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1151, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1152, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1153, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1154, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1155, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1156, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1157, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1158, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1159, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1160, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1161, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1162, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1163, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1164, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1165, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1166, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1167, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1168, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1169, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1170, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1171, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1172, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1173, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1174, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1175, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1176, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1177, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1178, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1179, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1180, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1181, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1182, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1183, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1184, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1185, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1186, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1187, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1188, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1189, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1190, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1191, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1192, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1193, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1194, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1195, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1196, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1197, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1198, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1199, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1200, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1201, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1202, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1203, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1204, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1205, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1206, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1207, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1208, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1209, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1210, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1211, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1212, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1213, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1214, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1215, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1216, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1217, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1218, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1219, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1220, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1221, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1222, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1223, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1224, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1225, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1226, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1227, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1228, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1229, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1230, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1231, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1232, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1233, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1234, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1235, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1236, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1237, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1238, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1239, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1240, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1241, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1242, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1243, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1244, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1245, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1246, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1247, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1248, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1249, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1250, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1251, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1252, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1253, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1254, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1255, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1256, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1257, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1258, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1259, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1260, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1261, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1262, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1263, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1264, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1265, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1266, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1267, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1268, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1269, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1270, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1271, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1272, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1273, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1274, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1275, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1276, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1277, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1278, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1279, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1280, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1281, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1282, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1283, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1284, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1285, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1286, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1287, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1288, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1289, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1290, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1291, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1292, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1293, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1294, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1295, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1296, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1297, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1298, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1299, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1300, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1301, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1302, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1303, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1304, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1305, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1306, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1307, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1308, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1309, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1310, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1311, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1312, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1313, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1314, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1315, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1316, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1317, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1318, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1319, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1320, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1321, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1322, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1323, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1324, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1325, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1326, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1327, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1328, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1329, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1330, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1331, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1332, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1333, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1334, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1335, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1336, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1337, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1338, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1339, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1340, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1341, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1342, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1343, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1344, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1345, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1346, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1347, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1348, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1349, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1350, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1351, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1352, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1353, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1354, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1355, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1356, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1357, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1358, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1359, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1360, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1361, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1362, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1363, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1364, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1365, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1366, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1367, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1368, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1369, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1370, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1371, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1372, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1373, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1374, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1375, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1376, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1377, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1378, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1379, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1380, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1381, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1382, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1383, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1384, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1385, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1386, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1387, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1388, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1389, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1390, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1391, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1392, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1393, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1394, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1395, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1396, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1397, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1398, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1399, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1400, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1401, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1402, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1403, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1404, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1405, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1406, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1407, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1408, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1409, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1410, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1411, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1412, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1413, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1414, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1415, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1416, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1417, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1418, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1419, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1420, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1421, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1422, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1423, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1424, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1425, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1426, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1427, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1428, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1429, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1430, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1431, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1432, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1433, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1434, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1435, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1436, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1437, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1438, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1439, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1440, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1441, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1442, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1443, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1444, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1445, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1446, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1447, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1448, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1449, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1450, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1451, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1452, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1453, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1454, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1455, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1456, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1457, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1458, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1459, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1460, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1461, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1462, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1463, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1464, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1465, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1466, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1467, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1468, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1469, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1470, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },
	{ .base = 1471, .cache = CACHE_NEVER, .buffer = BUFFER_NEVER, .type = TYPE_1MIB },

	/* Covering 1472 - 1472 MiB: SRAM */
	[1472] =
	{ .base = 1472, .cache = CACHE_SRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },

	/* Covering 1473 - 1535 MiB: unconnected */
	[1473] = {},

	/* Covering 1536 - 2559 MiB: unconnected, reserved */
	[1536] = {},

	/* Covering 2560 - 2591 MiB: SDRAM */
	[2560] =
	{ .base = 2560, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2561, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2562, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2563, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2564, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2565, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2566, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2567, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2568, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2569, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2570, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2571, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2572, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2573, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2574, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2575, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2576, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2577, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2578, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2579, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2580, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2581, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2582, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2583, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2584, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2585, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2586, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2587, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2588, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2589, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2590, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },
	{ .base = 2591, .cache = CACHE_SDRAM, .buffer = BUFFER_RAM, .type = TYPE_1MIB },

	/* Covering 2592 - 4095 MiB: unconnected */
	[2592] = {}
};

/** \brief activate the memory management unit */
void _mmuTableLoad() {
	/* set mmu domain */
	mmuSetDomains(0x0);
	mmuSetDomain(0, 0x3);
	/* load mmu base and activate the mm unit */
	mmuEnable(_mmuTable);
}

/** \brief override the mmu table given by remapping the virtual address to the
 * physical address and the vectors to the physical address and activate the mmu
 * \param table the mmu table to be overridden
 * \param virt virtual address (MiB aligned)
 * \param phys physical address (MiB aligned)
 * \param length length (in bytes) to be remapped */
__attribute__((const))
void _mmuTableRemap(struct SectionDescriptor * table, uint32_t virt,
	uint32_t phys, uint32_t length) {
	uint32_t i, segments;

	/* MMU works on a MiB boundary basis */
	phys >>= 20;
	virt >>= 20;
	segments = length >> 20;
	if (length & 0xfffff) {
		++segments;
	}

	/* remap vectors */
#ifdef REMAP_EXCEPTION_VECTORS
	table[0].base = phys;
	for (i = 1; i < 4; ++i) {
		table[i].type = TYPE_NOACCESS;
	}
#endif

	/* remap virt to phys */
	for (i = 0; i < segments; ++i) {
		table[virt + i].base = phys + i;
	}

	/* set mmu domain */
	mmuSetDomains(0x0);
	mmuSetDomain(0, 0x3);
	/* load mmu base and activate the mm unit */
	mmuEnable(table);

	_coreHardwareInit();
}
